@@ -20,13 +20,15 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 import warnings
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.bigquery_datatransfer_v1.services.data_transfer_service import pagers
 from google.cloud.bigquery_datatransfer_v1.types import datatransfer
 from google.cloud.bigquery_datatransfer_v1.types import transfer
@@ -183,10 +185,10 @@ class DataTransferServiceAsyncClient:
 
     async def get_data_source(
         self,
-        request: datatransfer.GetDataSourceRequest = None,
+        request: Union[datatransfer.GetDataSourceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.DataSource:
@@ -194,7 +196,7 @@ class DataTransferServiceAsyncClient:
         settings, which can be used for UI rendering.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.GetDataSourceRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.GetDataSourceRequest, dict]):
                 The request object. A request to get data source info.
             name (:class:`str`):
                 Required. The field will contain name of the resource
@@ -268,10 +270,10 @@ class DataTransferServiceAsyncClient:
 
     async def list_data_sources(
         self,
-        request: datatransfer.ListDataSourcesRequest = None,
+        request: Union[datatransfer.ListDataSourcesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDataSourcesAsyncPager:
@@ -279,7 +281,7 @@ class DataTransferServiceAsyncClient:
         settings, which can be used for UI rendering.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesRequest, dict]):
                 The request object. Request to list supported data
                 sources and their data transfer settings.
             parent (:class:`str`):
@@ -361,18 +363,18 @@ class DataTransferServiceAsyncClient:
 
     async def create_transfer_config(
         self,
-        request: datatransfer.CreateTransferConfigRequest = None,
+        request: Union[datatransfer.CreateTransferConfigRequest, dict] = None,
         *,
         parent: str = None,
         transfer_config: transfer.TransferConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferConfig:
         r"""Creates a new data transfer configuration.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.CreateTransferConfigRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.CreateTransferConfigRequest, dict]):
                 The request object. A request to create a data transfer
                 configuration. If new credentials are needed for this
                 transfer configuration, an authorization code must be
@@ -458,11 +460,11 @@ class DataTransferServiceAsyncClient:
 
     async def update_transfer_config(
         self,
-        request: datatransfer.UpdateTransferConfigRequest = None,
+        request: Union[datatransfer.UpdateTransferConfigRequest, dict] = None,
         *,
         transfer_config: transfer.TransferConfig = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferConfig:
@@ -470,7 +472,7 @@ class DataTransferServiceAsyncClient:
         All fields must be set, even if they are not updated.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.UpdateTransferConfigRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.UpdateTransferConfigRequest, dict]):
                 The request object. A request to update a transfer
                 configuration. To update the user id of the transfer
                 configuration, an authorization code needs to be
@@ -550,10 +552,10 @@ class DataTransferServiceAsyncClient:
 
     async def delete_transfer_config(
         self,
-        request: datatransfer.DeleteTransferConfigRequest = None,
+        request: Union[datatransfer.DeleteTransferConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -561,7 +563,7 @@ class DataTransferServiceAsyncClient:
         including any associated transfer runs and logs.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.DeleteTransferConfigRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.DeleteTransferConfigRequest, dict]):
                 The request object. A request to delete data transfer
                 information. All associated transfer runs and log
                 messages will be deleted as well.
@@ -628,17 +630,17 @@ class DataTransferServiceAsyncClient:
 
     async def get_transfer_config(
         self,
-        request: datatransfer.GetTransferConfigRequest = None,
+        request: Union[datatransfer.GetTransferConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferConfig:
         r"""Returns information about a data transfer config.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.GetTransferConfigRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.GetTransferConfigRequest, dict]):
                 The request object. A request to get data transfer
                 information.
             name (:class:`str`):
@@ -717,10 +719,10 @@ class DataTransferServiceAsyncClient:
 
     async def list_transfer_configs(
         self,
-        request: datatransfer.ListTransferConfigsRequest = None,
+        request: Union[datatransfer.ListTransferConfigsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferConfigsAsyncPager:
@@ -728,7 +730,7 @@ class DataTransferServiceAsyncClient:
         by a project in the specified location.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsRequest, dict]):
                 The request object. A request to list data transfers
                 configured for a BigQuery project.
             parent (:class:`str`):
@@ -809,12 +811,12 @@ class DataTransferServiceAsyncClient:
 
     async def schedule_transfer_runs(
         self,
-        request: datatransfer.ScheduleTransferRunsRequest = None,
+        request: Union[datatransfer.ScheduleTransferRunsRequest, dict] = None,
         *,
         parent: str = None,
         start_time: timestamp_pb2.Timestamp = None,
         end_time: timestamp_pb2.Timestamp = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.ScheduleTransferRunsResponse:
@@ -825,7 +827,7 @@ class DataTransferServiceAsyncClient:
         StartManualTransferRuns instead.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.ScheduleTransferRunsRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.ScheduleTransferRunsRequest, dict]):
                 The request object. A request to schedule transfer runs
                 for a time range.
             parent (:class:`str`):
@@ -910,9 +912,9 @@ class DataTransferServiceAsyncClient:
 
     async def start_manual_transfer_runs(
         self,
-        request: datatransfer.StartManualTransferRunsRequest = None,
+        request: Union[datatransfer.StartManualTransferRunsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.StartManualTransferRunsResponse:
@@ -922,7 +924,7 @@ class DataTransferServiceAsyncClient:
         and end_time (exclusive), or for a specific run_time.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.StartManualTransferRunsRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.StartManualTransferRunsRequest, dict]):
                 The request object. A request to start manual transfer
                 runs.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -962,10 +964,10 @@ class DataTransferServiceAsyncClient:
 
     async def get_transfer_run(
         self,
-        request: datatransfer.GetTransferRunRequest = None,
+        request: Union[datatransfer.GetTransferRunRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferRun:
@@ -973,7 +975,7 @@ class DataTransferServiceAsyncClient:
         run.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.GetTransferRunRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.GetTransferRunRequest, dict]):
                 The request object. A request to get data transfer run
                 information.
             name (:class:`str`):
@@ -1045,17 +1047,17 @@ class DataTransferServiceAsyncClient:
 
     async def delete_transfer_run(
         self,
-        request: datatransfer.DeleteTransferRunRequest = None,
+        request: Union[datatransfer.DeleteTransferRunRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes the specified transfer run.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.DeleteTransferRunRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.DeleteTransferRunRequest, dict]):
                 The request object. A request to delete data transfer
                 run information.
             name (:class:`str`):
@@ -1122,17 +1124,17 @@ class DataTransferServiceAsyncClient:
 
     async def list_transfer_runs(
         self,
-        request: datatransfer.ListTransferRunsRequest = None,
+        request: Union[datatransfer.ListTransferRunsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferRunsAsyncPager:
         r"""Returns information about running and completed jobs.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsRequest, dict]):
                 The request object. A request to list data transfer
                 runs. UI can use this method to show/filter specific
                 data transfer runs. The data source can use this method
@@ -1217,10 +1219,10 @@ class DataTransferServiceAsyncClient:
 
     async def list_transfer_logs(
         self,
-        request: datatransfer.ListTransferLogsRequest = None,
+        request: Union[datatransfer.ListTransferLogsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferLogsAsyncPager:
@@ -1228,7 +1230,7 @@ class DataTransferServiceAsyncClient:
         transfer run.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsRequest, dict]):
                 The request object. A request to get user facing log
                 messages associated with data transfer run.
             parent (:class:`str`):
@@ -1310,10 +1312,10 @@ class DataTransferServiceAsyncClient:
 
     async def check_valid_creds(
         self,
-        request: datatransfer.CheckValidCredsRequest = None,
+        request: Union[datatransfer.CheckValidCredsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.CheckValidCredsResponse:
@@ -1326,7 +1328,7 @@ class DataTransferServiceAsyncClient:
         can create a transfer config.
 
         Args:
-            request (:class:`google.cloud.bigquery_datatransfer_v1.types.CheckValidCredsRequest`):
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.CheckValidCredsRequest, dict]):
                 The request object. A request to determine whether the
                 user has valid credentials. This method is used to limit
                 the number of OAuth popups in the user interface. The
@@ -1403,6 +1405,12 @@ class DataTransferServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
