@@ -31,6 +31,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.bigquery_datatransfer_v1.services.data_transfer_service import pagers
 from google.cloud.bigquery_datatransfer_v1.types import datatransfer
 from google.cloud.bigquery_datatransfer_v1.types import transfer
@@ -388,10 +390,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def get_data_source(
@@ -399,7 +398,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.GetDataSourceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.DataSource:
@@ -474,7 +473,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.ListDataSourcesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDataSourcesPager:
@@ -558,7 +557,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         *,
         parent: str = None,
         transfer_config: transfer.TransferConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferConfig:
@@ -655,7 +654,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         *,
         transfer_config: transfer.TransferConfig = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferConfig:
@@ -746,7 +745,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.DeleteTransferConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -814,7 +813,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.GetTransferConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferConfig:
@@ -893,7 +892,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.ListTransferConfigsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferConfigsPager:
@@ -977,7 +976,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         parent: str = None,
         start_time: timestamp_pb2.Timestamp = None,
         end_time: timestamp_pb2.Timestamp = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.ScheduleTransferRunsResponse:
@@ -1075,7 +1074,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         self,
         request: Union[datatransfer.StartManualTransferRunsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.StartManualTransferRunsResponse:
@@ -1131,7 +1130,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.GetTransferRunRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> transfer.TransferRun:
@@ -1204,7 +1203,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.DeleteTransferRunRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1271,7 +1270,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.ListTransferRunsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferRunsPager:
@@ -1356,7 +1355,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.ListTransferLogsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferLogsPager:
@@ -1439,7 +1438,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         request: Union[datatransfer.CheckValidCredsRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.CheckValidCredsResponse:
@@ -1519,6 +1518,19 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
