@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,8 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple
+from typing import (
+    Any,
+    AsyncIterator,
+    Awaitable,
+    Callable,
+    Sequence,
+    Tuple,
+    Optional,
+    Iterator,
+)
 
 from google.cloud.bigquery_datatransfer_v1.types import datatransfer
 from google.cloud.bigquery_datatransfer_v1.types import transfer
@@ -25,7 +32,7 @@ class ListDataSourcesPager:
     """A pager for iterating through ``list_data_sources`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListDataSourcesResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``data_sources`` field.
 
@@ -34,7 +41,7 @@ class ListDataSourcesPager:
     through the ``data_sources`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListDataSourcesResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -52,9 +59,9 @@ class ListDataSourcesPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListDataSourcesRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListDataSourcesResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -68,14 +75,14 @@ class ListDataSourcesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datatransfer.ListDataSourcesResponse]:
+    def pages(self) -> Iterator[datatransfer.ListDataSourcesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[datatransfer.DataSource]:
+    def __iter__(self) -> Iterator[datatransfer.DataSource]:
         for page in self.pages:
             yield from page.data_sources
 
@@ -87,7 +94,7 @@ class ListDataSourcesAsyncPager:
     """A pager for iterating through ``list_data_sources`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListDataSourcesResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``data_sources`` field.
 
@@ -96,7 +103,7 @@ class ListDataSourcesAsyncPager:
     through the ``data_sources`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListDataSourcesResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -109,14 +116,14 @@ class ListDataSourcesAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListDataSourcesRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListDataSourcesResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -130,14 +137,14 @@ class ListDataSourcesAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datatransfer.ListDataSourcesResponse]:
+    async def pages(self) -> AsyncIterator[datatransfer.ListDataSourcesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[datatransfer.DataSource]:
+    def __aiter__(self) -> AsyncIterator[datatransfer.DataSource]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.data_sources:
@@ -153,7 +160,7 @@ class ListTransferConfigsPager:
     """A pager for iterating through ``list_transfer_configs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListTransferConfigsResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``transfer_configs`` field.
 
@@ -162,7 +169,7 @@ class ListTransferConfigsPager:
     through the ``transfer_configs`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListTransferConfigsResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -180,9 +187,9 @@ class ListTransferConfigsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListTransferConfigsRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListTransferConfigsResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -196,14 +203,14 @@ class ListTransferConfigsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datatransfer.ListTransferConfigsResponse]:
+    def pages(self) -> Iterator[datatransfer.ListTransferConfigsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[transfer.TransferConfig]:
+    def __iter__(self) -> Iterator[transfer.TransferConfig]:
         for page in self.pages:
             yield from page.transfer_configs
 
@@ -215,7 +222,7 @@ class ListTransferConfigsAsyncPager:
     """A pager for iterating through ``list_transfer_configs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListTransferConfigsResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``transfer_configs`` field.
 
@@ -224,7 +231,7 @@ class ListTransferConfigsAsyncPager:
     through the ``transfer_configs`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListTransferConfigsResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -237,14 +244,14 @@ class ListTransferConfigsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListTransferConfigsRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListTransferConfigsResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -258,14 +265,14 @@ class ListTransferConfigsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datatransfer.ListTransferConfigsResponse]:
+    async def pages(self) -> AsyncIterator[datatransfer.ListTransferConfigsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[transfer.TransferConfig]:
+    def __aiter__(self) -> AsyncIterator[transfer.TransferConfig]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.transfer_configs:
@@ -281,7 +288,7 @@ class ListTransferRunsPager:
     """A pager for iterating through ``list_transfer_runs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListTransferRunsResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``transfer_runs`` field.
 
@@ -290,7 +297,7 @@ class ListTransferRunsPager:
     through the ``transfer_runs`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListTransferRunsResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -308,9 +315,9 @@ class ListTransferRunsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListTransferRunsRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListTransferRunsResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -324,14 +331,14 @@ class ListTransferRunsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datatransfer.ListTransferRunsResponse]:
+    def pages(self) -> Iterator[datatransfer.ListTransferRunsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[transfer.TransferRun]:
+    def __iter__(self) -> Iterator[transfer.TransferRun]:
         for page in self.pages:
             yield from page.transfer_runs
 
@@ -343,7 +350,7 @@ class ListTransferRunsAsyncPager:
     """A pager for iterating through ``list_transfer_runs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListTransferRunsResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``transfer_runs`` field.
 
@@ -352,7 +359,7 @@ class ListTransferRunsAsyncPager:
     through the ``transfer_runs`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListTransferRunsResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -365,14 +372,14 @@ class ListTransferRunsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListTransferRunsRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListTransferRunsResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -386,14 +393,14 @@ class ListTransferRunsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datatransfer.ListTransferRunsResponse]:
+    async def pages(self) -> AsyncIterator[datatransfer.ListTransferRunsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[transfer.TransferRun]:
+    def __aiter__(self) -> AsyncIterator[transfer.TransferRun]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.transfer_runs:
@@ -409,7 +416,7 @@ class ListTransferLogsPager:
     """A pager for iterating through ``list_transfer_logs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListTransferLogsResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``transfer_messages`` field.
 
@@ -418,7 +425,7 @@ class ListTransferLogsPager:
     through the ``transfer_messages`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListTransferLogsResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -436,9 +443,9 @@ class ListTransferLogsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListTransferLogsRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListTransferLogsResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -452,14 +459,14 @@ class ListTransferLogsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[datatransfer.ListTransferLogsResponse]:
+    def pages(self) -> Iterator[datatransfer.ListTransferLogsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[transfer.TransferMessage]:
+    def __iter__(self) -> Iterator[transfer.TransferMessage]:
         for page in self.pages:
             yield from page.transfer_messages
 
@@ -471,7 +478,7 @@ class ListTransferLogsAsyncPager:
     """A pager for iterating through ``list_transfer_logs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.datatransfer.ListTransferLogsResponse` object, and
+    :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``transfer_messages`` field.
 
@@ -480,7 +487,7 @@ class ListTransferLogsAsyncPager:
     through the ``transfer_messages`` field on the
     corresponding responses.
 
-    All the usual :class:`~.datatransfer.ListTransferLogsResponse`
+    All the usual :class:`google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -493,14 +500,14 @@ class ListTransferLogsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.datatransfer.ListTransferLogsRequest`):
+            request (google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsRequest):
                 The initial request object.
-            response (:class:`~.datatransfer.ListTransferLogsResponse`):
+            response (google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -514,14 +521,14 @@ class ListTransferLogsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[datatransfer.ListTransferLogsResponse]:
+    async def pages(self) -> AsyncIterator[datatransfer.ListTransferLogsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[transfer.TransferMessage]:
+    def __aiter__(self) -> AsyncIterator[transfer.TransferMessage]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.transfer_messages:
