@@ -20,7 +20,6 @@ from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -650,5 +649,8 @@ class DataTransferServiceGrpcAsyncIOTransport(DataTransferServiceTransport):
             )
         return self._stubs["check_valid_creds"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("DataTransferServiceGrpcAsyncIOTransport",)
