@@ -236,6 +236,7 @@ class DataSource(proto.Message):
 
 class GetDataSourceRequest(proto.Message):
     r"""A request to get data source info.
+
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -275,6 +276,7 @@ class ListDataSourcesRequest(proto.Message):
 
 class ListDataSourcesResponse(proto.Message):
     r"""Returns list of supported data sources and their metadata.
+
     Attributes:
         data_sources (Sequence[google.cloud.bigquery_datatransfer_v1.types.DataSource]):
             List of supported data sources and their
@@ -419,6 +421,7 @@ class UpdateTransferConfigRequest(proto.Message):
 
 class GetTransferConfigRequest(proto.Message):
     r"""A request to get data transfer information.
+
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -447,6 +450,7 @@ class DeleteTransferConfigRequest(proto.Message):
 
 class GetTransferRunRequest(proto.Message):
     r"""A request to get data transfer run information.
+
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -461,6 +465,7 @@ class GetTransferRunRequest(proto.Message):
 
 class DeleteTransferRunRequest(proto.Message):
     r"""A request to delete data transfer run information.
+
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -504,6 +509,7 @@ class ListTransferConfigsRequest(proto.Message):
 
 class ListTransferConfigsResponse(proto.Message):
     r"""The returned list of pipelines in the project.
+
     Attributes:
         transfer_configs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferConfig]):
             Output only. The stored pipeline transfer
@@ -568,6 +574,7 @@ class ListTransferRunsRequest(proto.Message):
 
 class ListTransferRunsResponse(proto.Message):
     r"""The returned list of pipelines in the project.
+
     Attributes:
         transfer_runs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferRun]):
             Output only. The stored pipeline transfer
@@ -624,6 +631,7 @@ class ListTransferLogsRequest(proto.Message):
 
 class ListTransferLogsResponse(proto.Message):
     r"""The returned list transfer run messages.
+
     Attributes:
         transfer_messages (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferMessage]):
             Output only. The stored pipeline transfer
@@ -678,6 +686,7 @@ class CheckValidCredsResponse(proto.Message):
 
 class ScheduleTransferRunsRequest(proto.Message):
     r"""A request to schedule transfer runs for a time range.
+
     Attributes:
         parent (str):
             Required. Transfer configuration name in the form:
@@ -698,6 +707,7 @@ class ScheduleTransferRunsRequest(proto.Message):
 
 class ScheduleTransferRunsResponse(proto.Message):
     r"""A response to schedule transfer runs for a time range.
+
     Attributes:
         runs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferRun]):
             The transfer runs that were scheduled.
@@ -708,6 +718,14 @@ class ScheduleTransferRunsResponse(proto.Message):
 
 class StartManualTransferRunsRequest(proto.Message):
     r"""A request to start manual transfer runs.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         parent (str):
             Transfer configuration name in the form:
@@ -716,9 +734,11 @@ class StartManualTransferRunsRequest(proto.Message):
         requested_time_range (google.cloud.bigquery_datatransfer_v1.types.StartManualTransferRunsRequest.TimeRange):
             Time range for the transfer runs that should
             be started.
+            This field is a member of `oneof`_ ``time``.
         requested_run_time (google.protobuf.timestamp_pb2.Timestamp):
             Specific run_time for a transfer run to be started. The
             requested_run_time must not be in the future.
+            This field is a member of `oneof`_ ``time``.
     """
 
     class TimeRange(proto.Message):
@@ -759,6 +779,7 @@ class StartManualTransferRunsRequest(proto.Message):
 
 class StartManualTransferRunsResponse(proto.Message):
     r"""A response to start manual transfer runs.
+
     Attributes:
         runs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferRun]):
             The transfer runs that were created.
